# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from typing import TYPE_CHECKING

from azure.mgmt.core import ARMPipelineClient
from msrest import Deserializer, Serializer

if TYPE_CHECKING:
    # pylint: disable=unused-import,ungrouped-imports
    from typing import Any, Optional

    from azure.core.credentials import TokenCredential

from ._configuration import AzureMachineLearningWorkspacesConfiguration
from .operations import OnlineEndpointsOperations
from .operations import Operations
from .operations import ProfilesOperations
from .operations import ServicesOperations
from . import models


class AzureMachineLearningWorkspaces(object):
    """These APIs allow end users to manage Azure Machine Learning Models, Images, Profiles, and Services.

    :ivar online_endpoints: OnlineEndpointsOperations operations
    :vartype online_endpoints: azure.mgmt.machinelearningservices.operations.OnlineEndpointsOperations
    :ivar operations: Operations operations
    :vartype operations: azure.mgmt.machinelearningservices.operations.Operations
    :ivar profiles: ProfilesOperations operations
    :vartype profiles: azure.mgmt.machinelearningservices.operations.ProfilesOperations
    :ivar services: ServicesOperations operations
    :vartype services: azure.mgmt.machinelearningservices.operations.ServicesOperations
    :param credential: Credential needed for the client to connect to Azure.
    :type credential: ~azure.core.credentials.TokenCredential
    :param str base_url: Service URL
    """

    def __init__(
        self,
        credential,  # type: "TokenCredential"
        base_url=None,  # type: Optional[str]
        **kwargs  # type: Any
    ):
        # type: (...) -> None
        if not base_url:
            base_url = 'https://management.azure.com'
        self._config = AzureMachineLearningWorkspacesConfiguration(credential, **kwargs)
        self._client = ARMPipelineClient(base_url=base_url, config=self._config, **kwargs)

        client_models = {k: v for k, v in models.__dict__.items() if isinstance(v, type)}
        self._serialize = Serializer(client_models)
        self._serialize.client_side_validation = False
        self._deserialize = Deserializer(client_models)

        self.online_endpoints = OnlineEndpointsOperations(
            self._client, self._config, self._serialize, self._deserialize)
        self.operations = Operations(
            self._client, self._config, self._serialize, self._deserialize)
        self.profiles = ProfilesOperations(
            self._client, self._config, self._serialize, self._deserialize)
        self.services = ServicesOperations(
            self._client, self._config, self._serialize, self._deserialize)

    def close(self):
        # type: () -> None
        self._client.close()

    def __enter__(self):
        # type: () -> AzureMachineLearningWorkspaces
        self._client.__enter__()
        return self

    def __exit__(self, *exc_details):
        # type: (Any) -> None
        self._client.__exit__(*exc_details)
